searchData={"items":[{"type":"module","title":"Posthog","doc":"A comprehensive Elixir client for PostHog's analytics and feature flag APIs.\n\nThis module provides a high-level interface to PostHog's APIs, allowing you to:\n- Track user events and actions\n- Manage and evaluate feature flags\n- Handle multivariate testing\n- Process events in batch\n- Work with user, group, and person properties","ref":"Posthog.html"},{"type":"module","title":"Configuration - Posthog","doc":"Add your PostHog configuration to your application config:\n\n    config :posthog,\n      api_url: \"https://app.posthog.com\",  # Or your self-hosted instance\n      api_key: \"phc_your_project_api_key\"\n\nOptional configuration:\n\n    config :posthog,\n      json_library: Jason,   # Default JSON parser (optional)\n      enabled_capture: true  # Whether to enable PostHog tracking (optional, defaults to true)\n                             # Set to false in development/test environments to disable tracking","ref":"Posthog.html#module-configuration"},{"type":"module","title":"Disabling PostHog - Posthog","doc":"You can disable PostHog tracking by setting `enabled: false` in your configuration.\nThis is particularly useful in development or test environments where you don't want\nto send actual events to PostHog.\n\nWhen `enabled_capture` is set to `false`:\n- All `Posthog.capture/3` and `Posthog.batch/2` calls will succeed silently\n- PostHog will still communicate with the server for Feature Flags\n\nThis is useful for:\n- Development and test environments where you don't want to pollute your PostHog instance\n- Situations where you need to temporarily disable tracking\n\nExample configuration for development:\n\n    # config/dev.exs\n    config :posthog,\n      enabled_capture: false  # Disable tracking in development\n\nExample configuration for test:\n\n    # config/test.exs\n    config :posthog,\n      enabled_capture: false  # Disable tracking in test environment","ref":"Posthog.html#module-disabling-posthog"},{"type":"module","title":"Event Tracking - Posthog","doc":"Events can be tracked with various levels of detail:\n\n    # Basic event\n    Posthog.capture(\"page_view\", distinct_id: \"user_123\")\n\n    # Event with properties\n    Posthog.capture(\"purchase\", %{\n      distinct_id: \"user_123\",\n      product_id: \"prod_123\",\n      price: 99.99\n    })\n\n    # Event with custom timestamp\n    Posthog.capture(\"signup\", \"user_123\", %{}, timestamp: DateTime.utc_now())\n\n    # Event with custom headers (e.g., for IP forwarding)\n    Posthog.capture(\"login\", \"user_123\", %{}, headers: [{\"x-forwarded-for\", \"127.0.0.1\"}])","ref":"Posthog.html#module-event-tracking"},{"type":"module","title":"Feature Flags - Posthog","doc":"PostHog feature flags can be used for feature management and A/B testing:\n\n    # Get all feature flags for a user\n    {:ok, flags} = Posthog.feature_flags(\"user_123\")\n\n    # Check specific feature flag\n    {:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n\n    # Quick boolean check\n    if Posthog.feature_flag_enabled?(\"new-feature\", \"user_123\") do\n      # Show new feature\n    end\n\n    # Feature flags with group/person properties\n    Posthog.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}},\n      person_properties: %{email: \"user@example.com\"}\n    )","ref":"Posthog.html#module-feature-flags"},{"type":"module","title":"Batch Processing - Posthog","doc":"Multiple events can be sent in a single request for better performance:\n\n    events = [\n      {\"page_view\", [distinct_id: \"user_123\"], nil},\n      {\"button_click\", [distinct_id: \"user_123\", button: \"signup\"], nil}\n    ]\n\n    Posthog.batch(events)\n\nEach event in the batch is a tuple of `{event_name, properties, timestamp}`.","ref":"Posthog.html#module-batch-processing"},{"type":"function","title":"Posthog.batch/2","doc":"Sends multiple events to PostHog in a single request.","ref":"Posthog.html#batch/2"},{"type":"function","title":"Parameters - Posthog.batch/2","doc":"* `events` - List of event tuples in the format `{event_name, distinct_id, properties}`\n  * `opts` - Optional parameters for the batch request","ref":"Posthog.html#batch/2-parameters"},{"type":"function","title":"Examples - Posthog.batch/2","doc":"events = [\n      {\"page_view\", \"user_123\", %{}},\n      {\"button_click\", \"user_123\", %{button: \"signup\"}}\n    ]\n\n    Posthog.batch(events)","ref":"Posthog.html#batch/2-examples"},{"type":"function","title":"Posthog.capture/4","doc":"Captures an event in PostHog.","ref":"Posthog.html#capture/4"},{"type":"function","title":"Parameters - Posthog.capture/4","doc":"* `event` - The name of the event (string or atom)\n  * `params` - Required parameters including `:distinct_id` and optional properties\n  * `opts` - Optional parameters that can be either a timestamp or a keyword list of options","ref":"Posthog.html#capture/4-parameters"},{"type":"function","title":"Options - Posthog.capture/4","doc":"* `:headers` - Additional HTTP headers for the request\n  * `:groups` - Group properties for the event\n  * `:group_properties` - Additional properties for groups\n  * `:person_properties` - Properties for the person\n  * `:timestamp` - Custom timestamp for the event","ref":"Posthog.html#capture/4-options"},{"type":"function","title":"Examples - Posthog.capture/4","doc":"# Basic event\n    Posthog.capture(\"page_view\", \"user_123\")\n\n    # Event with properties\n    Posthog.capture(\"purchase\", \"user_123\", %{\n      product_id: \"prod_123\",\n      price: 99.99\n    })\n\n    # Event with timestamp\n    Posthog.capture(\"signup\", \"user_123\", %{}, timestamp: DateTime.utc_now())\n\n    # Event with custom headers\n    Posthog.capture(\"login\", \"user_123\", %{}, headers: [{\"x-forwarded-for\", \"127.0.0.1\"}])","ref":"Posthog.html#capture/4-examples"},{"type":"function","title":"Posthog.feature_flag/3","doc":"Retrieves information about a specific feature flag for a given distinct ID.","ref":"Posthog.html#feature_flag/3"},{"type":"function","title":"Parameters - Posthog.feature_flag/3","doc":"* `flag` - The name of the feature flag\n  * `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flag/3-parameters"},{"type":"function","title":"Examples - Posthog.feature_flag/3","doc":"# Boolean feature flag\n    {:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{name: \"new-dashboard\", payload: true, enabled: true}\n\n    # Multivariate feature flag\n    {:ok, flag} = Posthog.feature_flag(\"pricing-test\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{\n    #   name: \"pricing-test\",\n    #   payload: %{\"price\" => 99, \"period\" => \"monthly\"},\n    #   enabled: \"variant-a\"\n    # }","ref":"Posthog.html#feature_flag/3-examples"},{"type":"function","title":"Posthog.feature_flag_enabled?/3","doc":"Checks if a feature flag is enabled for a given distinct ID.\n\nThis is a convenience function that returns a boolean instead of a result tuple.\nFor multivariate flags, returns true if the flag has any value set.","ref":"Posthog.html#feature_flag_enabled?/3"},{"type":"function","title":"Parameters - Posthog.feature_flag_enabled?/3","doc":"* `flag` - The name of the feature flag\n  * `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flag_enabled?/3-parameters"},{"type":"function","title":"Examples - Posthog.feature_flag_enabled?/3","doc":"if Posthog.feature_flag_enabled?(\"new-dashboard\", \"user_123\") do\n      # Show new dashboard\n    end","ref":"Posthog.html#feature_flag_enabled?/3-examples"},{"type":"function","title":"Posthog.feature_flags/2","doc":"Retrieves all feature flags for a given distinct ID.","ref":"Posthog.html#feature_flags/2"},{"type":"function","title":"Parameters - Posthog.feature_flags/2","doc":"* `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.html#feature_flags/2-parameters"},{"type":"function","title":"Options - Posthog.feature_flags/2","doc":"* `:groups` - Group properties for feature flag evaluation\n  * `:group_properties` - Additional properties for groups\n  * `:person_properties` - Properties for the person","ref":"Posthog.html#feature_flags/2-options"},{"type":"function","title":"Examples - Posthog.feature_flags/2","doc":"# Basic feature flags request\n    {:ok, flags} = Posthog.feature_flags(\"user_123\")\n\n    # With group properties\n    {:ok, flags} = Posthog.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}}\n    )","ref":"Posthog.html#feature_flags/2-examples"},{"type":"module","title":"Posthog.Application","doc":"The main application module for PostHog Elixir client.\n\nThis module handles the application lifecycle and supervises the necessary processes\nfor the PostHog client to function properly. It primarily manages the Cachex instance\nused for feature flag event deduplication.","ref":"Posthog.Application.html"},{"type":"module","title":"Features - Posthog.Application","doc":"* Validates configuration before starting\n* Manages a Cachex instance for feature flag event deduplication\n* Implements LRU (Least Recently Used) caching strategy\n* Automatically prunes cache entries to maintain size limits","ref":"Posthog.Application.html#module-features"},{"type":"module","title":"Cache Configuration - Posthog.Application","doc":"The Cachex instance is configured with:\n* Maximum of 50,000 entries (matching posthog-python's limit)\n* LRU (Least Recently Used) eviction policy\n* Automatic pruning every 10 seconds\n* Access tracking for LRU implementation","ref":"Posthog.Application.html#module-cache-configuration"},{"type":"module","title":"Usage - Posthog.Application","doc":"The application is automatically started by the Elixir runtime when included\nin your application's supervision tree. You don't need to start it manually.\n\nTo access the cache name in your code:\n\n    Posthog.Application.cache_name()\n    # Returns: :posthog_feature_flag_cache","ref":"Posthog.Application.html#module-usage"},{"type":"function","title":"Posthog.Application.cache_name/0","doc":"Returns the name of the Cachex instance used for feature flag event deduplication.","ref":"Posthog.Application.html#cache_name/0"},{"type":"function","title":"Returns - Posthog.Application.cache_name/0","doc":"* `atom()` - The cache name, always `:posthog_feature_flag_cache` at the moment","ref":"Posthog.Application.html#cache_name/0-returns"},{"type":"function","title":"Examples - Posthog.Application.cache_name/0","doc":"iex> Posthog.Application.cache_name()\n    :posthog_feature_flag_cache","ref":"Posthog.Application.html#cache_name/0-examples"},{"type":"function","title":"Posthog.Application.start/2","doc":"Starts the PostHog application.\n\nThis callback is called by the Elixir runtime when the application starts.\nIt performs the following tasks:\n1. Validates the PostHog configuration\n2. Sets up the Cachex instance for feature flag event deduplication\n3. Starts the supervision tree","ref":"Posthog.Application.html#start/2"},{"type":"function","title":"Parameters - Posthog.Application.start/2","doc":"* `_type` - The type of start (ignored)\n  * `args` - Keyword list of arguments, can include:","ref":"Posthog.Application.html#start/2-parameters"},{"type":"function","title":"Returns - Posthog.Application.start/2","doc":"* `{:ok, pid()}` on successful start\n  * `{:error, term()}` on failure","ref":"Posthog.Application.html#start/2-returns"},{"type":"function","title":"Examples - Posthog.Application.start/2","doc":"# Start with default configuration\n    Posthog.Application.start(:normal, [])","ref":"Posthog.Application.html#start/2-examples"},{"type":"module","title":"Posthog.Client","doc":"Low-level HTTP client for interacting with PostHog's API.\n\nThis module handles the direct HTTP communication with PostHog's API endpoints.\nIt provides functions for:\n- Sending event capture requests\n- Processing batch events\n- Retrieving feature flag information\n\nWhile this module can be used directly, it's recommended to use the higher-level\nfunctions in the `Posthog` module instead.","ref":"Posthog.Client.html"},{"type":"module","title":"Configuration - Posthog.Client","doc":"The client uses the following configuration from your application:\n\n    config :posthog,\n      api_url: \"https://app.posthog.com\",  # Required\n      api_key: \"phc_your_project_api_key\", # Required\n      json_library: Jason,                 # Optional (default: Jason)\n      enabled_capture: true,               # Optional (default: true)\n      http_client: Posthog.HTTPClient.Hackney,  # Optional (default: Posthog.HTTPClient.Hackney)\n      http_client_opts: [                  # Optional\n        timeout: 5_000,    # 5 seconds\n        retries: 3,        # Number of retries\n        retry_delay: 1_000 # 1 second between retries\n      ]","ref":"Posthog.Client.html#module-configuration"},{"type":"module","title":"Disabling capture - Posthog.Client","doc":"When `enabled_capture` is set to `false`:\n- All `Posthog.capture/3` and `Posthog.batch/3` calls will succeed silently\n- PostHog will still communicate with the server for Feature Flags\n\nThis is useful for:\n- Development and test environments where you don't want to pollute your PostHog instance\n- Situations where you need to temporarily disable tracking\n\nExample configuration for disabling the client:\n\n    # config/dev.exs or config/test.exs\n    config :posthog,\n      enabled_capture: false","ref":"Posthog.Client.html#module-disabling-capture"},{"type":"module","title":"API Endpoints - Posthog.Client","doc":"The client interacts with the following PostHog API endpoints:\n- `/capture` - For sending individual and batch events\n- `/decide` - For retrieving feature flag information","ref":"Posthog.Client.html#module-api-endpoints"},{"type":"module","title":"Error Handling - Posthog.Client","doc":"All functions return a result tuple:\n- `{:ok, response}` for successful requests\n- `{:error, response}` for failed requests with a response\n- `{:error, term()}` for other errors (network issues, etc.)","ref":"Posthog.Client.html#module-error-handling"},{"type":"module","title":"Examples - Posthog.Client","doc":"# Capture an event\n    Posthog.Client.capture(\"page_view\", \"user_123\")\n\n    # Send batch events\n    events = [\n      {\"page_view\", \"user_123\", %{}},\n      {\"click\", \"user_123\", %{}}\n    ]\n    Posthog.Client.batch(events, timestamp: DateTime.utc_now())\n\n    # Get feature flags\n    Posthog.Client.feature_flags(\"user_123\", groups: %{team: \"engineering\"})","ref":"Posthog.Client.html#module-examples"},{"type":"function","title":"Posthog.Client.batch/2","doc":"Sends multiple events to PostHog in a single request.","ref":"Posthog.Client.html#batch/2"},{"type":"function","title":"Parameters - Posthog.Client.batch/2","doc":"* `events` - List of event tuples in the format `{event_name, distinct_id, properties}`\n  * `opts` - Additional options (see `t:opts/0`)\n  * `headers` - Additional HTTP headers","ref":"Posthog.Client.html#batch/2-parameters"},{"type":"function","title":"Examples - Posthog.Client.batch/2","doc":"events = [\n      {\"page_view\", \"user_123\", %{}},\n      {\"click\", \"user_123\", %{button: \"signup\"}}\n    ]\n\n    Posthog.Client.batch(events, %{timestamp: DateTime.utc_now()})","ref":"Posthog.Client.html#batch/2-examples"},{"type":"function","title":"Posthog.Client.batch/3","doc":"","ref":"Posthog.Client.html#batch/3"},{"type":"type","title":"Posthog.Client.cache_key/0","doc":"Cache key for the `$feature_flag_called` event.","ref":"Posthog.Client.html#t:cache_key/0"},{"type":"function","title":"Posthog.Client.capture/4","doc":"Captures a single event in PostHog.","ref":"Posthog.Client.html#capture/4"},{"type":"function","title":"Parameters - Posthog.Client.capture/4","doc":"* `event` - The name of the event (string or atom)\n  * `params` - Event properties including `:distinct_id`\n  * `opts` - Additional options (see `t:opts/0`)","ref":"Posthog.Client.html#capture/4-parameters"},{"type":"function","title":"Examples - Posthog.Client.capture/4","doc":"# Basic event\n    Posthog.Client.capture(\"page_view\", \"user_123\")\n\n    # Event with properties and timestamp\n    Posthog.Client.capture(\"purchase\", \"user_123\", %{\n      product_id: \"123\",\n      price: 99.99\n    }, timestamp: DateTime.utc_now())\n\n    # Event with custom headers\n    Posthog.Client.capture(\"login\", \"user_123\", %{}, headers: [{\"x-forwarded-for\", \"127.0.0.1\"}])","ref":"Posthog.Client.html#capture/4-examples"},{"type":"type","title":"Posthog.Client.distinct_id/0","doc":"Distinct ID for the person or group.","ref":"Posthog.Client.html#t:distinct_id/0"},{"type":"type","title":"Posthog.Client.event/0","doc":"Event name, can be either an atom or a binary string.","ref":"Posthog.Client.html#t:event/0"},{"type":"function","title":"Posthog.Client.feature_flag/3","doc":"Retrieves information about a specific feature flag for a given distinct ID.","ref":"Posthog.Client.html#feature_flag/3"},{"type":"function","title":"Parameters - Posthog.Client.feature_flag/3","doc":"* `flag` - The name of the feature flag\n  * `distinct_id` - The unique identifier for the user\n  * `opts` - Optional parameters for the feature flag request","ref":"Posthog.Client.html#feature_flag/3-parameters"},{"type":"function","title":"Examples - Posthog.Client.feature_flag/3","doc":"# Boolean feature flag\n    {:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{name: \"new-dashboard\", payload: true, enabled: true}\n\n    # Multivariate feature flag\n    {:ok, flag} = Posthog.feature_flag(\"pricing-test\", \"user_123\")\n    # Returns: %Posthog.FeatureFlag{\n    #   name: \"pricing-test\",\n    #   payload: %{\"price\" => 99, \"period\" => \"monthly\"},\n    #   enabled: \"variant-a\"\n    # }","ref":"Posthog.Client.html#feature_flag/3-examples"},{"type":"type","title":"Posthog.Client.feature_flag_opts/0","doc":"Feature flag specific options that should not be passed to capture events.\n\n* `:send_feature_flag_event` - Whether to capture the `$feature_flag_called` event (default: true)","ref":"Posthog.Client.html#t:feature_flag_opts/0"},{"type":"function","title":"Posthog.Client.feature_flags/2","doc":"Retrieves feature flags for a given distinct ID.","ref":"Posthog.Client.html#feature_flags/2"},{"type":"function","title":"Parameters - Posthog.Client.feature_flags/2","doc":"* `distinct_id` - The unique identifier for the user\n  * `opts` - Additional options (see `t:opts/0`)","ref":"Posthog.Client.html#feature_flags/2-parameters"},{"type":"function","title":"Examples - Posthog.Client.feature_flags/2","doc":"# Basic feature flags request\n    Posthog.Client.feature_flags(\"user_123\")\n\n    # With group properties\n    Posthog.Client.feature_flags(\"user_123\",\n      groups: %{company: \"company_123\"},\n      group_properties: %{company: %{industry: \"tech\"}}\n    )","ref":"Posthog.Client.html#feature_flags/2-examples"},{"type":"type","title":"Posthog.Client.headers/0","doc":"HTTP headers in the format expected by :hackney.","ref":"Posthog.Client.html#t:headers/0"},{"type":"type","title":"Posthog.Client.opts/0","doc":"Options that can be passed to API requests.\n\n* `:headers` - Additional HTTP headers to include in the request\n* `:groups` - Group properties for feature flag evaluation\n* `:group_properties` - Additional properties for groups\n* `:person_properties` - Properties for the person\n* `:timestamp` - Custom timestamp for events\n* `:uuid` - Custom UUID for the event","ref":"Posthog.Client.html#t:opts/0"},{"type":"type","title":"Posthog.Client.properties/0","doc":"Properties that can be attached to events or feature flag requests.","ref":"Posthog.Client.html#t:properties/0"},{"type":"type","title":"Posthog.Client.response/0","doc":"Response from the PostHog API.\nContains the status code, headers, and parsed JSON body (if any).","ref":"Posthog.Client.html#t:response/0"},{"type":"type","title":"Posthog.Client.result/0","doc":"Result of a PostHog operation.","ref":"Posthog.Client.html#t:result/0"},{"type":"type","title":"Posthog.Client.timestamp/0","doc":"Timestamp for events. Can be a DateTime, NaiveDateTime, or ISO8601 string.","ref":"Posthog.Client.html#t:timestamp/0"},{"type":"module","title":"Posthog.Config","doc":"Handles configuration validation and defaults for the PostHog client.\n\nThis module validates the configuration at compile time and provides\nsensible defaults for optional values.","ref":"Posthog.Config.html"},{"type":"function","title":"Posthog.Config.api_key/0","doc":"Validates and returns the API key from the configuration.\n\nRaises a helpful error message if the key is missing or invalid.","ref":"Posthog.Config.html#api_key/0"},{"type":"function","title":"Posthog.Config.api_url/0","doc":"Validates and returns the API URL from the configuration.\n\nRaises a helpful error message if the URL is missing or invalid.","ref":"Posthog.Config.html#api_url/0"},{"type":"function","title":"Posthog.Config.enabled_capture?/0","doc":"Returns whether event capture is enabled.\n\nDefaults to true if not configured.","ref":"Posthog.Config.html#enabled_capture?/0"},{"type":"function","title":"Posthog.Config.http_client/0","doc":"Returns the HTTP client module to use.\n\nDefaults to Posthog.HTTPClient.Hackney if not configured.","ref":"Posthog.Config.html#http_client/0"},{"type":"function","title":"Posthog.Config.http_client_opts/0","doc":"Returns the HTTP client options.\n\nDefaults to:\n- timeout: 5_000 (5 seconds)\n- retries: 3\n- retry_delay: 1_000 (1 second)","ref":"Posthog.Config.html#http_client_opts/0"},{"type":"function","title":"Posthog.Config.json_library/0","doc":"Returns the JSON library to use for encoding/decoding.\n\nDefaults to Jason if not configured.","ref":"Posthog.Config.html#json_library/0"},{"type":"function","title":"Posthog.Config.validate_config!/0","doc":"Validates the entire PostHog configuration at compile time.\n\nThis ensures that all required configuration is present and valid\nbefore the application starts.","ref":"Posthog.Config.html#validate_config!/0"},{"type":"module","title":"Posthog.Event","doc":"Represents a PostHog event with all its properties and metadata.\n\nThis struct encapsulates all the information needed to send an event to PostHog,\nincluding the event name, distinct ID, properties, timestamp, and UUID.","ref":"Posthog.Event.html"},{"type":"module","title":"Examples - Posthog.Event","doc":"# Create a basic event\n    iex> event = Posthog.Event.new(\"page_view\", \"user_123\")\n    iex> event.event\n    \"page_view\"\n    iex> event.distinct_id\n    \"user_123\"\n    iex> event.properties\n    %{}\n    iex> is_binary(event.uuid)\n    true\n    iex> is_binary(event.timestamp)\n    true\n\n    # Create an event with properties\n    iex> event = Posthog.Event.new(\"purchase\", \"user_123\", %{price: 99.99})\n    iex> event.properties\n    %{price: 99.99}\n\n    # Create an event with custom timestamp\n    iex> timestamp = \"2023-01-01T00:00:00Z\"\n    iex> event = Posthog.Event.new(\"login\", \"user_123\", %{}, timestamp: timestamp)\n    iex> event.timestamp\n    \"2023-01-01T00:00:00Z\"\n\n    # Create an event with custom UUID\n    iex> uuid = \"123e4567-e89b-12d3-a456-426614174000\"\n    iex> event = Posthog.Event.new(\"signup\", \"user_123\", %{}, uuid: uuid)\n    iex> event.uuid\n    \"123e4567-e89b-12d3-a456-426614174000\"\n\n    # Convert event to API payload\n    iex> event = Posthog.Event.new(\"page_view\", \"user_123\", %{page: \"home\"})\n    iex> payload = Posthog.Event.to_api_payload(event)\n    iex> payload.event\n    \"page_view\"\n    iex> payload.distinct_id\n    \"user_123\"\n    iex> payload.properties[\"page\"]\n    \"home\"\n    iex> payload.properties[\"$lib\"]\n    \"posthog-elixir\"\n    iex> is_binary(payload.uuid)\n    true\n    iex> is_binary(payload.timestamp)\n    true\n\n    # Create batch payload\n    iex> events = [\n    ...>   Posthog.Event.new(\"page_view\", \"user_123\", %{page: \"home\"}),\n    ...>   Posthog.Event.new(\"click\", \"user_123\", %{button: \"signup\"})\n    ...> ]\n    iex> batch = Posthog.Event.batch_payload(events)\n    iex> length(batch.batch)\n    2\n    iex> [first, second] = batch.batch\n    iex> first.event\n    \"page_view\"\n    iex> second.event\n    \"click\"","ref":"Posthog.Event.html#module-examples"},{"type":"function","title":"Posthog.Event.batch_payload/1","doc":"Creates a batch payload from a list of events.","ref":"Posthog.Event.html#batch_payload/1"},{"type":"type","title":"Posthog.Event.distinct_id/0","doc":"","ref":"Posthog.Event.html#t:distinct_id/0"},{"type":"type","title":"Posthog.Event.event_name/0","doc":"","ref":"Posthog.Event.html#t:event_name/0"},{"type":"function","title":"Posthog.Event.new/4","doc":"Creates a new PostHog event.","ref":"Posthog.Event.html#new/4"},{"type":"function","title":"Parameters - Posthog.Event.new/4","doc":"* `event` - The name of the event (string or atom)\n  * `distinct_id` - The distinct ID for the person or group\n  * `properties` - Event properties (optional, defaults to empty map)\n  * `timestamp` - Optional timestamp for the event (defaults to current UTC time)\n  * `uuid` - Optional UUID for the event (defaults to a new UUID7)","ref":"Posthog.Event.html#new/4-parameters"},{"type":"function","title":"Examples - Posthog.Event.new/4","doc":"# Basic event\n    Posthog.Event.new(\"page_view\", \"user_123\")\n\n    # Event with properties\n    Posthog.Event.new(\"purchase\", \"user_123\", %{price: 99.99})\n\n    # Event with custom timestamp\n    Posthog.Event.new(\"login\", \"user_123\", %{}, timestamp: DateTime.utc_now())","ref":"Posthog.Event.html#new/4-examples"},{"type":"type","title":"Posthog.Event.properties/0","doc":"","ref":"Posthog.Event.html#t:properties/0"},{"type":"type","title":"Posthog.Event.t/0","doc":"","ref":"Posthog.Event.html#t:t/0"},{"type":"type","title":"Posthog.Event.timestamp/0","doc":"","ref":"Posthog.Event.html#t:timestamp/0"},{"type":"function","title":"Posthog.Event.to_api_payload/1","doc":"Converts the event struct to a map suitable for sending to the PostHog API.","ref":"Posthog.Event.html#to_api_payload/1"},{"type":"module","title":"Posthog.FeatureFlag","doc":"Represents a PostHog feature flag with its evaluation state.\n\nThis module provides a struct and helper functions for working with PostHog feature flags.\nFeature flags can be either boolean (on/off) or multivariate (multiple variants).","ref":"Posthog.FeatureFlag.html"},{"type":"module","title":"Structure - Posthog.FeatureFlag","doc":"The `FeatureFlag` struct contains:\n  * `name` - The name of the feature flag\n  * `payload` - The payload value associated with the flag (can be any term)\n  * `enabled` - The evaluation result (boolean for on/off flags, string for multivariate flags)","ref":"Posthog.FeatureFlag.html#module-structure"},{"type":"module","title":"Examples - Posthog.FeatureFlag","doc":"# Boolean feature flag\n    %Posthog.FeatureFlag{\n      name: \"new-dashboard\",\n      payload: true,\n      enabled: true\n    }\n\n    # Multivariate feature flag\n    %Posthog.FeatureFlag{\n      name: \"pricing-test\",\n      payload: %{\"price\" => 99, \"period\" => \"monthly\"},\n      enabled: \"variant-a\"\n    }","ref":"Posthog.FeatureFlag.html#module-examples"},{"type":"function","title":"Posthog.FeatureFlag.boolean?/1","doc":"Checks if a feature flag is a boolean flag.\n\nReturns `true` if the flag is a boolean (on/off) flag, `false` if it's a multivariate flag.","ref":"Posthog.FeatureFlag.html#boolean?/1"},{"type":"function","title":"Examples - Posthog.FeatureFlag.boolean?/1","doc":"flag = Posthog.FeatureFlag.new(\"new-dashboard\", true, true)\n    Posthog.FeatureFlag.boolean?(flag)\n    # Returns: true\n\n    flag = Posthog.FeatureFlag.new(\"pricing-test\", \"variant-a\", %{})\n    Posthog.FeatureFlag.boolean?(flag)\n    # Returns: false","ref":"Posthog.FeatureFlag.html#boolean?/1-examples"},{"type":"function","title":"Posthog.FeatureFlag.decode_payload/1","doc":"Decodes a feature flag payload from JSON string to Elixir term.\nReturns the original payload if it's not a valid JSON string.","ref":"Posthog.FeatureFlag.html#decode_payload/1"},{"type":"function","title":"Examples - Posthog.FeatureFlag.decode_payload/1","doc":"# JSON string payload\n    Posthog.FeatureFlag.decode_payload(\"{\"color\": \"blue\"}\")\n    # Returns: %{\"color\" => \"blue\"}\n\n    # Non-JSON string payload\n    Posthog.FeatureFlag.decode_payload(\"plain-text\")\n    # Returns: \"plain-text\"\n\n    # Nil payload\n    Posthog.FeatureFlag.decode_payload(nil)\n    # Returns: nil","ref":"Posthog.FeatureFlag.html#decode_payload/1-examples"},{"type":"function","title":"Posthog.FeatureFlag.decode_payloads/1","doc":"Decodes a map of feature flag payloads.","ref":"Posthog.FeatureFlag.html#decode_payloads/1"},{"type":"function","title":"Parameters - Posthog.FeatureFlag.decode_payloads/1","doc":"* `payloads` - Map of feature flag names to their payload values","ref":"Posthog.FeatureFlag.html#decode_payloads/1-parameters"},{"type":"function","title":"Examples - Posthog.FeatureFlag.decode_payloads/1","doc":"payloads = %{\n      \"my-flag\" => \"{\"color\": \"blue\"}\",\n      \"other-flag\" => \"plain-text\"\n    }\n    Posthog.FeatureFlag.decode_payloads(payloads)\n    # Returns: %{\n    #   \"my-flag\" => %{\"color\" => \"blue\"},\n    #   \"other-flag\" => \"plain-text\"\n    # }","ref":"Posthog.FeatureFlag.html#decode_payloads/1-examples"},{"type":"type","title":"Posthog.FeatureFlag.flag_response/0","doc":"The response format from PostHog's feature flag API.\nContains both the flag states and their associated payloads.","ref":"Posthog.FeatureFlag.html#t:flag_response/0"},{"type":"function","title":"Posthog.FeatureFlag.new/3","doc":"Creates a new FeatureFlag struct.","ref":"Posthog.FeatureFlag.html#new/3"},{"type":"function","title":"Parameters - Posthog.FeatureFlag.new/3","doc":"* `name` - The name of the feature flag\n  * `enabled` - The evaluation result (boolean or string)\n  * `payload` - The payload value associated with the flag","ref":"Posthog.FeatureFlag.html#new/3-parameters"},{"type":"function","title":"Examples - Posthog.FeatureFlag.new/3","doc":"# Create a boolean feature flag\n    Posthog.FeatureFlag.new(\"new-dashboard\", true, true)\n\n    # Create a multivariate feature flag\n    Posthog.FeatureFlag.new(\"pricing-test\", \"variant-a\",\n      %{\"price\" => 99, \"period\" => \"monthly\"})","ref":"Posthog.FeatureFlag.html#new/3-examples"},{"type":"function","title":"Posthog.FeatureFlag.process_response/1","doc":"Processes a feature flag response from the PostHog API.\nHandles both v3 and v4 API response formats.","ref":"Posthog.FeatureFlag.html#process_response/1"},{"type":"function","title":"Parameters - Posthog.FeatureFlag.process_response/1","doc":"* `response` - The raw response from the API","ref":"Posthog.FeatureFlag.html#process_response/1-parameters"},{"type":"function","title":"Examples - Posthog.FeatureFlag.process_response/1","doc":"# v4 API response\n    response = %{\n      \"flags\" => %{\n        \"my-flag\" => %{\n          \"enabled\" => true,\n          \"variant\" => nil,\n          \"metadata\" => %{\"payload\" => \"{\"color\": \"blue\"}\"}\n        }\n      },\n      \"requestId\" => \"123\"\n    }\n    Posthog.FeatureFlag.process_response(response)\n    # Returns: %{\n    #   flags: %{\"my-flag\" => %{\"enabled\" => true, \"variant\" => nil, \"metadata\" => %{\"payload\" => \"{\"color\": \"blue\"}\"}}},\n    #   feature_flags: %{\"my-flag\" => true},\n    #   feature_flag_payloads: %{\"my-flag\" => %{\"color\" => \"blue\"}},\n    #   request_id: \"123\"\n    # }\n\n    # v3 API response\n    response = %{\n      \"featureFlags\" => %{\"my-flag\" => true},\n      \"featureFlagPayloads\" => %{\"my-flag\" => \"{\"color\": \"blue\"}\"},\n      \"requestId\" => \"123\"\n    }\n    Posthog.FeatureFlag.process_response(response)\n    # Returns: %{\n    #   feature_flags: %{\"my-flag\" => true},\n    #   feature_flag_payloads: %{\"my-flag\" => %{\"color\" => \"blue\"}},\n    #   request_id: \"123\"\n    # }","ref":"Posthog.FeatureFlag.html#process_response/1-examples"},{"type":"type","title":"Posthog.FeatureFlag.properties/0","doc":"A map of properties that can be associated with a feature flag.","ref":"Posthog.FeatureFlag.html#t:properties/0"},{"type":"type","title":"Posthog.FeatureFlag.t/0","doc":"The FeatureFlag struct type.\n\nFields:\n  * `name` - The name of the feature flag (string)\n  * `payload` - The payload value associated with the flag (any term)\n  * `enabled` - The evaluation result (boolean or string)","ref":"Posthog.FeatureFlag.html#t:t/0"},{"type":"type","title":"Posthog.FeatureFlag.variant/0","doc":"Represents the enabled state of a feature flag.\nCan be either a boolean for on/off flags or a string for multivariate flags.","ref":"Posthog.FeatureFlag.html#t:variant/0"},{"type":"module","title":"Posthog.Guard","doc":"Custom guards for the Posthog library.\n\nThis module contains guard expressions that can be used across the Posthog library\nfor consistent pattern matching and type checking.","ref":"Posthog.Guard.html"},{"type":"macro","title":"Posthog.Guard.is_keyword_list/1","doc":"Guard that checks if a term is a keyword list.\n\nA keyword list is a list of 2-tuples where the first element of each tuple\nis an atom.","ref":"Posthog.Guard.html#is_keyword_list/1"},{"type":"macro","title":"Examples - Posthog.Guard.is_keyword_list/1","doc":"iex> import Posthog.Guard\n    iex> match?({:ok, val} when is_keyword_list(val), {:ok, [foo: 1, bar: 2]})\n    true\n    iex> match?({:ok, val} when is_keyword_list(val), {:ok, [{:a, 1}, {:b, 2}]})\n    true\n    iex> match?({:ok, val} when is_keyword_list(val), {:ok, [{1, 2}, {3, 4}]})\n    false","ref":"Posthog.Guard.html#is_keyword_list/1-examples"},{"type":"behaviour","title":"Posthog.HTTPClient","doc":"Behaviour for HTTP client implementations.\n\nThis allows for easy swapping of HTTP clients and better testability.","ref":"Posthog.HTTPClient.html"},{"type":"type","title":"Posthog.HTTPClient.body/0","doc":"","ref":"Posthog.HTTPClient.html#t:body/0"},{"type":"type","title":"Posthog.HTTPClient.headers/0","doc":"","ref":"Posthog.HTTPClient.html#t:headers/0"},{"type":"callback","title":"Posthog.HTTPClient.post/4","doc":"Makes a POST request to the given URL with the specified body and headers.\n\nReturns `{:ok, response}` on success or `{:error, reason}` on failure.","ref":"Posthog.HTTPClient.html#c:post/4"},{"type":"type","title":"Posthog.HTTPClient.response/0","doc":"","ref":"Posthog.HTTPClient.html#t:response/0"},{"type":"type","title":"Posthog.HTTPClient.url/0","doc":"","ref":"Posthog.HTTPClient.html#t:url/0"},{"type":"module","title":"Posthog.HTTPClient.Hackney","doc":"Hackney-based implementation of the Posthog.HTTPClient behaviour.","ref":"Posthog.HTTPClient.Hackney.html"},{"type":"extras","title":"PostHog Elixir Client","doc":"# PostHog Elixir Client\n\n[![Hex.pm](https://img.shields.io/hexpm/v/posthog.svg)](https://hex.pm/packages/posthog)\n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/posthog)\n\nA powerful Elixir client for [PostHog](https://posthog.com), providing seamless integration with PostHog's analytics and feature flag APIs.","ref":"readme.html"},{"type":"extras","title":"Features - PostHog Elixir Client","doc":"- Event Capture: Track user actions and custom events\n- Feature Flags: Manage feature flags and multivariate tests\n- Batch Processing: Send multiple events efficiently\n- Custom Properties: Support for user, group, and person properties\n- Flexible Configuration: Customizable JSON library and API version\n- Environment Control: Disable tracking in development/test environments\n- Configurable HTTP Client: Customizable timeouts, retries, and HTTP client implementation","ref":"readme.html#features"},{"type":"extras","title":"Installation - PostHog Elixir Client","doc":"Add `posthog` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:posthog, \"~> 1.0\"}\n  ]\nend\n```\n\nYou'll also need to include this library under your application tree. You can do so by including `:posthog` under your `:extra_applications` key inside `mix.exs`\n\n```elixir\n# mix.exs\ndef application do\n  [\n    extra_applications: [\n      # ... your existing applications\n      :posthog\n    ]\n  ]\n```\n\nor if you already have a `YourApp.Application` application, you can also add `Posthog.Application` under your supervision tree:\n\n```elixir\n# lib/my_app/application.ex\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Your other children...\n      {Posthog.Application, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Application Customization - PostHog Elixir Client","doc":"This library includes a `Posthog.Application` because we bundle `Cachex` to allow you to track inside PostHog your FF usage.\n\nThis cache is located under `:posthog_feature_flag_cache`. If you want more control over the application, you can init it yourself in your own `application.ex`\n\n```elixir\n# lib/my_app/application.ex\n\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Your other application children...\n      {Posthog.Application, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"readme.html#application-customization"},{"type":"extras","title":"Configuration - PostHog Elixir Client","doc":"Add your PostHog configuration to your application's config:\n\n```elixir\n# config/config.exs\nconfig :posthog,\n  api_url: \"https://us.posthog.com\",  # Or `https://eu.posthog.com` or your self-hosted PostHog instance URL\n  api_key: \"phc_your_project_api_key\"\n\n# Optional configurations\nconfig :posthog,\n  json_library: Jason,   # Default JSON parser (optional)\n  capture_enabled: true, # Whether to enable PostHog tracking (optional, defaults to true)\n  http_client: Posthog.HTTPClient.Hackney,  # Default HTTP client (optional)\n  http_client_opts: [    # HTTP client options (optional)\n    timeout: 5_000,      # Request timeout in milliseconds (default: 5_000)\n    retries: 3,          # Number of retries on failure (default: 3)\n    retry_delay: 1_000   # Delay between retries in milliseconds (default: 1_000)\n  ]\n```","ref":"readme.html#configuration"},{"type":"extras","title":"HTTP Client Configuration - PostHog Elixir Client","doc":"The library uses Hackney as the default HTTP client, but you can configure its behavior or even swap it for a different implementation by simply implementing the `Posthog.HTTPClient` behavior:\n\n```elixir\n# config/config.exs\nconfig :posthog,\n  # Use a different HTTP client implementation\n  http_client: MyCustomHTTPClient,\n\n  # Configure HTTP client options\n  http_client_opts: [\n    timeout: 10_000,   # 10 seconds timeout\n    retries: 5,        # 5 retries\n    retry_delay: 2_000 # 2 seconds between retries\n  ]\n```\n\nFor testing, you might want to use a mock HTTP client:\n\n```elixir\n# test/support/mocks.ex\ndefmodule Posthog.HTTPClient.Test do\n  @behaviour Posthog.HTTPClient\n\n  def post(url, body, headers, _opts) do\n    # Return mock responses for testing\n    {:ok, %{status: 200, headers: [], body: %{}}}\n  end\nend\n\n# config/test.exs\nconfig :posthog,\n  http_client: Posthog.HTTPClient.Test\n```","ref":"readme.html#http-client-configuration"},{"type":"extras","title":"Disabling PostHog capture - PostHog Elixir Client","doc":"You can disable PostHog tracking by setting `enabled_capture: false` in your configuration. This is particularly useful in development or test environments where you don't want to send actual events to PostHog.\n\nWhen `enabled_capture` is set to `false`:\n\n- All `Posthog.capture/3` and `Posthog.batch/2` calls will succeed silently\n- PostHog will still communicate with the server for Feature Flags\n\nThis is useful for:\n\n- Development and test environments where you don't want to pollute your PostHog instance\n- Situations where you need to temporarily disable tracking\n\nExample configuration for development:\n\n```elixir\n# config/dev.exs\nconfig :posthog,\n  enabled_capture: false  # Disable tracking in development\n```\n\nExample configuration for test:\n\n```elixir\n# config/test.exs\nconfig :posthog,\n  enabled_capture: false  # Disable tracking in test environment\n```","ref":"readme.html#disabling-posthog-capture"},{"type":"extras","title":"Usage - PostHog Elixir Client","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Capturing Events - PostHog Elixir Client","doc":"Simple event capture:\n\n```elixir\n# Basic event with `event` and `distinct_id`, both required\nPosthog.capture(\"page_view\", \"user_123\")\n\n# Event with properties\nPosthog.capture(\"purchase\", \"user_123\", %{\n    product_id: \"prod_123\",\n    price: 99.99,\n    currency: \"USD\"\n})\n\n# Event with custom timestamp\nPosthog.capture(\"signup_completed\", \"user_123\", %{}, timestamp: DateTime.utc_now())\n\n# Event with custom UUID\nuuid = \"...\"\nPosthog.capture(\"signup_completed\", \"user_123\", %{}, uuid: uuid)\n\n# Event with custom headers\nPosthog.capture(\n  \"login\",\n  \"user_123\",\n  %{},\n  headers: [{\"x-forwarded-for\", \"127.0.0.1\"}]\n)\n```","ref":"readme.html#capturing-events"},{"type":"extras","title":"Batch Processing - PostHog Elixir Client","doc":"Send multiple events in a single request:\n\n```elixir\nevents = [\n  {\"page_view\", \"user_123\", %{}},\n  {\"button_click\", \"user_123\", %{button_id: \"signup\"}}\n]\n\nPosthog.batch(events)\n```","ref":"readme.html#batch-processing"},{"type":"extras","title":"Feature Flags - PostHog Elixir Client","doc":"Get all feature flags for a user:\n\n```elixir\n{:ok, flags} = Posthog.feature_flags(\"user_123\")\n\n# Response format:\n# %{\n#   \"featureFlags\" => %{\"flag-1\" => true, \"flag-2\" => \"variant-b\"},\n#   \"featureFlagPayloads\" => %{\n#     \"flag-1\" => true,\n#     \"flag-2\" => %{\"color\" => \"blue\", \"size\" => \"large\"}\n#   }\n# }\n```\n\nCheck specific feature flag:\n\n```elixir\n# Boolean feature flag\n{:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\")\n# Returns: %Posthog.FeatureFlag{name: \"new-dashboard\", payload: true, enabled: true}\n\n# Multivariate feature flag\n{:ok, flag} = Posthog.feature_flag(\"pricing-test\", \"user_123\")\n# Returns: %Posthog.FeatureFlag{\n#   name: \"pricing-test\",\n#   payload: %{\"price\" => 99, \"period\" => \"monthly\"},\n#   enabled: \"variant-a\"\n# }\n\n# Quick boolean check\nif Posthog.feature_flag_enabled?(\"new-dashboard\", \"user_123\") do\n  # Show new dashboard\nend\n```\n\nFeature flags with group properties:\n\n```elixir\nPosthog.feature_flags(\"user_123\",\n  groups: %{company: \"company_123\"},\n  group_properties: %{company: %{industry: \"tech\"}},\n  person_properties: %{email: \"user@example.com\"}\n)\n```\n\n#### Stop sending `$feature_flag_called`\n\nWe automatically send `$feature_flag_called` events so that you can properly keep track of which feature flags you're accessing via `Posthog.feature_flag()` calls. If you wanna save some events, you can disable this by adding `send_feature_flag_event: false` to the call:\n\n```elixir\n# Boolean feature flag\n{:ok, flag} = Posthog.feature_flag(\"new-dashboard\", \"user_123\", send_feature_flag_event: false)\n```","ref":"readme.html#feature-flags"},{"type":"extras","title":"Local Development - PostHog Elixir Client","doc":"Run `bin/setup` to install development dependencies or run the following commands manually:\n\nWe recommend using `asdf` to manage Elixir and Erlang versions:\n\n```sh\n# Install required versions\nasdf install\n\n# Install dependencies\nmix deps.get\nmix compile\n```\n\nRun tests:\n\n```sh\nbin/test\n```\n\n(This runs `mix test`).\n\nFormat code:\n\n```sh\nbin/fmt\n```","ref":"readme.html#local-development"},{"type":"extras","title":"Troubleshooting - PostHog Elixir Client","doc":"If you encounter WX library issues during Erlang installation:\n\n```sh\n# Disable WX during installation\nexport KERL_CONFIGURE_OPTIONS=\"--without-wx\"\n```\n\nTo persist this setting, add it to your shell configuration file (`~/.bashrc`, `~/.zshrc`, or `~/.profile`).","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Examples - PostHog Elixir Client","doc":"There's an example console project in `examples/feature_flag_demo` that shows how to use the client. Follow the instructions in [the README](examples/feature_flag_demo/README.md) to run it.","ref":"readme.html#examples"},{"type":"extras","title":"Development Tools - PostHog Elixir Client","doc":"This project uses several development tools to maintain code quality and security:","ref":"readme.html#development-tools"},{"type":"extras","title":"Credo - PostHog Elixir Client","doc":"Credo is a static code analysis tool that helps enforce coding standards and catch potential issues. Run it with:\n\n```bash\nmix credo --strict\n```\n\nFor more detailed output:\n\n```bash\nmix credo --strict --verbose\n```","ref":"readme.html#credo"},{"type":"extras","title":"Mix Audit - PostHog Elixir Client","doc":"Mix Audit helps identify security vulnerabilities in dependencies. Run it with:\n\n```bash\nmix deps.audit\n```","ref":"readme.html#mix-audit"},{"type":"extras","title":"Contributing - PostHog Elixir Client","doc":"When contributing to this project, please ensure your code passes all the development tool checks:\n\n1. Run Credo to ensure code style consistency\n2. Run Mix Audit to check for security vulnerabilities\n3. Run Mix Unused to identify any unused code\n4. Run the test suite with `mix test`","ref":"readme.html#contributing"},{"type":"extras","title":"License - PostHog Elixir Client","doc":"This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"1.0.1 - 2025-04-17 - CHANGELOG","doc":"- Small changes to docs [f3578a7006fb8d6cb19f36e19b1387243a12bd21]","ref":"changelog.html#1-0-1-2025-04-17"},{"type":"extras","title":"1.0.0 - 2025-04-17 - CHANGELOG","doc":"","ref":"changelog.html#1-0-0-2025-04-17"},{"type":"extras","title":"Big Release - CHANGELOG","doc":"`posthog-elixir` is now officially stable and running on v1. There are some breaking changes and some general improvements. Check [MIGRATION.md](./MIGRATION.md#v0-v1) for a guide on how to migrate.","ref":"changelog.html#big-release"},{"type":"extras","title":"What's changed - CHANGELOG","doc":"- Elixir v1.14+ is now a requirement\n- Feature Flags now return a key called `payload` rather than `value` to better align with the other SDKs\n- PostHog now requires you to initialize `Posthog.Application` alongside your supervisor tree. This is required because of our `Cachex` system to properly track your FF usage.\n  - We'll also include local evaluation in the near term, which will also require a GenServer, therefore, requiring us to use a Supervisor.\n- Added `enabled_capture` configuration option to disable PostHog tracking in development/test environments\n- `Posthog.capture` now requires `distinct_id` as a required second argument","ref":"changelog.html#what-s-changed"},{"type":"extras","title":"0.4.4 - 2025-04-14 - CHANGELOG","doc":"Fix inconsistent docs for properties - [#13]","ref":"changelog.html#0-4-4-2025-04-14"},{"type":"extras","title":"0.4.3 - 2025-04-14 - CHANGELOG","doc":"Improve docs setup - [#12]","ref":"changelog.html#0-4-3-2025-04-14"},{"type":"extras","title":"0.4.2 - 2025-03-27 - CHANGELOG","doc":"Allow `atom()` property keys - [#11]","ref":"changelog.html#0-4-2-2025-03-27"},{"type":"extras","title":"0.4.1 - 2025-03-12 - CHANGELOG","doc":"Fix feature flags broken implementation - [#10]","ref":"changelog.html#0-4-1-2025-03-12"},{"type":"extras","title":"0.4.0 - 2025-02-11 - CHANGELOG","doc":"Documentation + OTP/Elixir version bumps","ref":"changelog.html#0-4-0-2025-02-11"},{"type":"extras","title":"0.3.0 - 2025-01-09 - CHANGELOG","doc":"- Initial feature flags implementation (#7)","ref":"changelog.html#0-3-0-2025-01-09"},{"type":"extras","title":"0.2.0 - 2024-05-04 - CHANGELOG","doc":"- Allow extra headers (#3)","ref":"changelog.html#0-2-0-2024-05-04"},{"type":"extras","title":"0.1.0 - 2020-06-06 - CHANGELOG","doc":"- Initial release","ref":"changelog.html#0-1-0-2020-06-06"},{"type":"extras","title":"Migration","doc":"# Migration\n\nThis is a migration guide for all major version bumps","ref":"migration.html"},{"type":"extras","title":"v0-v1 - Migration","doc":"When we stabilized our library, we decided to pull some breaking changes, here are they and how you can migrate:","ref":"migration.html#v0-v1"},{"type":"extras","title":"Minimum Elixir version bumped to v1.14 - Migration","doc":"The library previously supported Elixir v1.12+. You'll need to migrate to Elixir v1.14 - at least. Elixir v1.14 was launched more than 2.5 years ago, and we believe that should be enough time for you to migrate. You can check Elixir's own release announcements to understand how you should proceed with the migration.\n\n- https://elixir-lang.org/blog/2021/12/03/elixir-v1-13-0-released/\n- https://elixir-lang.org/blog/2022/09/01/elixir-v1-14-0-released/","ref":"migration.html#minimum-elixir-version-bumped-to-v1-14"},{"type":"extras","title":"Decide v4 - Feature Flags - Migration","doc":"PostHog is consistently upgrading our internal data representation so that's better for customers each and every time. We've recently launched a new version of our `/decide` endpoint called `v4`. This endpoint is slightly different, which caused a small change in behavior for our flags.\n\n`Posthog.FeatureFlag` previously included a key `value` that to represent the internal structure of a flag. It was renamed to `payload` to:\n\n1. better represent the fact that it can be both an object and a boolean\n2. align it more closely with our other SDKs","ref":"migration.html#decide-v4-feature-flags"},{"type":"extras","title":"Posthog.Application - Migration","doc":"This library now depends on `Cachex`, and includes a supervision tree. There are 2 options:\n\n1. If you have a simple application without a `YourApp.Application` application, then you can simply add `:posthog` to your `mix.exs` `application` definition\n\n```elixir\ndef application do\n    [\n      extra_applications: [\n        # ... your existing applications ...\n        :posthog\n      ],\n    ]\n  end\n```\n\n2. Or, if you're already using an Application, you can add add `Posthog.Application` to your own supervision tree:\n\n```elixir\n# lib/my_app/application.ex\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Your other children...\n      {Posthog.Application, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\n### `Posthog.capture` new signature\n\nThe signature to `Posthog.capture` has changed. `distinct_id` is now a required argument.\n\nHere are some examples on how the method is now used:\n\n```elixir\n# Basic event with `event` and `distinct_id`, both required\nPosthog.capture(\"page_view\", \"user_123\")\n\n# Event with properties\nPosthog.capture(\"purchase\", \"user_123\", %{\n    product_id: \"prod_123\",\n    price: 99.99,\n    currency: \"USD\"\n})\n\n# Event with custom timestamp\nPosthog.capture(\"signup_completed\", \"user_123\", %{}, timestamp: DateTime.utc_now())\n\n# Event with custom UUID\nuuid = \"...\"\nPosthog.capture(\"signup_completed\", \"user_123\", %{}, uuid: uuid)\n\n# Event with custom headers\nPosthog.capture(\n  \"login\",\n  \"user_123\",\n  %{},\n  headers: [{\"x-forwarded-for\", \"127.0.0.1\"}]\n)\n```","ref":"migration.html#posthog-application"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}